
<h1 align="center">
IsImport is required Module Checker and Installer.
</h1>

> **[`Example`](#)**

usage of `isimport` module.
```python
from isimport import myModule

mymodule = ["rich", "tqdm", "py2cpy", "android-sdk"]

myModule(mymodule)
print("OK")
```